@@ -44,7 +44,7 @@ extern zend_module_entry yaf_module_entry;
 # define ZEND_ACC_DTOR	0x0
 #endif
 
-#define PHP_YAF_VERSION 					"3.0.8"
+#define PHP_YAF_VERSION 					"3.0.9"
 
 #define YAF_STARTUP_FUNCTION(module)   	ZEND_MINIT_FUNCTION(yaf_##module)
 #define YAF_RINIT_FUNCTION(module)		ZEND_RINIT_FUNCTION(yaf_##module)
@@ -122,6 +122,10 @@ extern ZEND_DECLARE_MODULE_GLOBALS(yaf);
 
 #endif
 
+#if PHP_VERSION_ID >= 70400
+typedef unsigned long ulong;
+#endif
+
 /*
  * Local variables:
  * tab-width: 4
